@@ -3,6 +3,10 @@ utils::globalVariables(c("self", "super"), package = "renv")
 
 renv_tests_reporter <- function() {
 
+  # if we're running on CI, use the default reporter
+  if (!is.na(Sys.getenv("CI", unset = NA)))
+    return(testthat::default_reporter())
+
   # if we can't load R6, use the default reporter
   if (!requireNamespace("R6", quietly = TRUE))
     return(testthat::default_reporter())
@@ -13,6 +17,9 @@ renv_tests_reporter <- function() {
     classname = "RenvReporter",
     inherit   = testthat::CheckReporter,
 
+    lock_class   = FALSE,
+    lock_objects = FALSE,
+
     public = list(
 
       .time = NULL,
