@@ -51,6 +51,10 @@ local({
   
   }
   
+  renv_bootstrap_tests_running <- function() {
+    getOption("renv.tests.running", default = FALSE)
+  }
+  
   renv_bootstrap_repos <- function() {
   
     # check for repos override
@@ -59,7 +63,7 @@ local({
       return(repos)
   
     # if we're testing, re-use the test repositories
-    if (renv_tests_running())
+    if (renv_bootstrap_tests_running())
       return(getOption("renv.tests.repos"))
   
     # retrieve current repos
@@ -119,7 +123,7 @@ local({
     if (fixup)
       mode <- "w+b"
   
-    download.file(
+    utils::download.file(
       url      = url,
       destfile = destfile,
       mode     = mode,
@@ -135,7 +139,12 @@ local({
     message("* Downloading renv ", version, " from CRAN ... ", appendLF = FALSE)
   
     info <- tryCatch(
-      download.packages("renv", repos = repos, destdir = tempdir(), quiet = TRUE),
+      utils::download.packages(
+        pkgs = "renv",
+        repos = repos,
+        destdir = tempdir(),
+        quiet = TRUE
+      ),
       condition = identity
     )
   
@@ -156,7 +165,10 @@ local({
     for (repos in all) {
   
       db <- tryCatch(
-        as.data.frame(available.packages(repos = repos), stringsAsFactors = FALSE),
+        as.data.frame(
+          x = utils::available.packages(repos = repos),
+          stringsAsFactors = FALSE
+        ),
         error = identity
       )
   
@@ -242,7 +254,7 @@ local({
       return(FALSE)
     }
   
-    message("Done!")
+    message("OK")
     return(destfile)
   
   }
