@@ -33,3 +33,21 @@ test_that("we can query actions when no lockfile has yet been generated", {
   actions <- actions("snapshot")
   expect_true(nrow(actions) == 1L)
 })
+
+test_that("bare usages of actions work as expected", {
+
+  # set up project with 3 packages that need to be snapshotted
+  renv_tests_scope("bread")
+  renv_scope_options(renv.config.auto.snapshot = FALSE)
+
+  init()
+  install("breakfast")
+
+  writeLines("library(breakfast)", con = "deps.R")
+  acts <- actions("snapshot")
+
+  expect_true(nrow(acts) == 3)
+  expect_setequal(acts$Package, c("breakfast", "oatmeal", "toast"))
+  expect_true(all(acts$Action == "install"))
+
+})
