@@ -4,10 +4,12 @@ context("Bioconductor")
 test_that("packages can be installed, restored from Bioconductor", {
 
   skip_on_cran()
-  skip_on_appveyor()
+  skip_on_os("windows")
   skip_if(getRversion() < "3.5.0")
   skip_if(R.version$nickname == "Unsuffered Consequences")
 
+  renv_scope_options(renv.tests.verbose = FALSE)
+
   renv_tests_scope("Biobase")
 
   cran <- "https://cloud.r-project.org"
@@ -43,15 +45,19 @@ test_that("packages can be installed, restored from Bioconductor", {
 test_that("renv::install(<bioc>, rebuild = TRUE) works", {
 
   skip_on_cran()
-  skip_on_appveyor()
+  skip_on_os("windows")
   skip_if(getRversion() < "3.5.0")
   skip_if(R.version$nickname == "Unsuffered Consequences")
   skip_if_not_installed("BiocManager")
 
+  renv_scope_options(renv.tests.verbose = FALSE)
+
   requireNamespace("BiocManager", quietly = TRUE)
   on.exit(unloadNamespace("BiocManager"), add = TRUE)
 
   renv_tests_scope()
   install("bioc::Biobase", rebuild = TRUE)
 
+  expect_true(renv_package_installed("Biobase"))
+
 })
