@@ -53,7 +53,7 @@ test_that("we can parse a GitHub remotes specification", {
 
 test_that("we can parse a GitHub remotes specification with 'wininet'", {
   skip_on_cran()
-  skip_on_appveyor()
+  skip_on_os("windows")
   skip_if_not(renv_platform_windows())
 
   renv_scope_envvars(RENV_DOWNLOAD_FILE_METHOD = "wininet")
