@@ -8,7 +8,7 @@ test_that("all renv paths live within tempdir() during tests", {
 })
 
 test_that("the cache path can be set through an environment variable", {
-  cachepath <- renv_tempfile("renv-cache-")
+  cachepath <- renv_tempfile_path("renv-cache-")
   renv_scope_envvars(RENV_PATHS_CACHE = cachepath)
   expect_true(startswith(renv_paths_cache(), cachepath))
 })
