@@ -8,7 +8,7 @@ python <-
 
 test_that("we can activate Python with a project", {
 
-  skip_on_appveyor()
+  skip_on_os("windows")
   skip_on_cran()
   skip_if_no_python(python)
 
@@ -22,7 +22,7 @@ test_that("we can activate Python with a project", {
 
 test_that("we can activate Python with a virtualenv in a project", {
 
-  skip_on_appveyor()
+  skip_on_os("windows")
   skip_on_cran()
   skip_if_no_virtualenv(python)
 
@@ -38,7 +38,7 @@ test_that("installed Python packages are snapshotted / restored [virtualenv]", {
 
   skip_if_local()
   skip_on_travis()
-  skip_on_appveyor()
+  skip_on_os("windows")
   skip_on_cran()
   skip_if_no_virtualenv(python)
 
@@ -87,7 +87,7 @@ test_that("installed Python packages are snapshotted / restored [conda]", {
 
   skip_if_local()
   skip_on_travis()
-  skip_on_appveyor()
+  skip_on_os("windows")
   skip_on_cran()
   skip_if_no_miniconda(python)
 
